
.. _tauruscustomsettings:

=======================
Taurus custom settings
=======================


Taurus provides a module located at its root directory called
`tauruscustomsettings`.

.. automodule:: taurus.tauruscustomsettings
   :members:
   :undoc-members:
